@@ -22,11 +22,11 @@ WebService::DataDog - Interface to DataDog's REST API.
 
 =head1 VERSION
 
-Version 0.4.0
+Version 0.5.0
 
 =cut
 
-our $VERSION = '0.4.0';
+our $VERSION = '0.5.0';
 
 
 =head1 SYNOPSIS
@@ -220,10 +220,19 @@ sub build
 		croak 'Please specify the name of the module to build'
 			if !defined( $module ) || ( $module eq '' );
 		
+		# Load the class corresponding to the submodule requested.
 		my $class = __PACKAGE__ . '::' . $module;
-		
 		Class::Load::load_class( $class ) || croak "Failed to load $class, double-check the class name";
-		my $object = bless( $self, $class ); # Copy internals of factory so we have connection information
+		
+		# Instantiate a new object of that class. Since it's a subclass
+		# of WebService::DataDog, we pass all the non-hidden properties
+		# of the datadog object to build it.
+		my $object = $class->new(
+			map { $_ => $self->{$_} }
+			grep { substr( $_, 0, 1 ) ne '_' }
+			keys %$self
+		);
+		
 		return $object;
 }
 
@@ -429,9 +438,10 @@ L<http://search.cpan.org/dist/WebService-DataDog/>
 Thanks to ThinkGeek (<http://www.thinkgeek.com/>) and its corporate overlords at
 Geeknet (<http://www.geek.net/>), for footing the bill while I write code for them!
 
-Special thanks for architecture advice from fellow ThinkGeek CPAN author Guillaume
-Aubert L<http://search.cpan.org/~aubertg/> as well as fellow ThinkGeek CPAN author
-Kate Kirby L<http://search.cpan.org/~kate/>
+Special thanks for architecture advice, and code contributions, from fellow
+ThinkGeek CPAN author Guillaume Aubert L<http://search.cpan.org/~aubertg/> as 
+well as architecture advice from fellow ThinkGeek CPAN author Kate 
+Kirby L<http://search.cpan.org/~kate/>.
 
 =head1 COPYRIGHT & LICENSE
 
